<?php
function custom_post_type_store_system() {
    $labels = array(
        'name'               => __( 'Hệ Thống Cửa Hàng', 'text-domain' ),
        'singular_name'      => __( 'Cửa Hàng', 'text-domain' ),
        'menu_name'          => __( 'Hệ Thống Cửa Hàng', 'text-domain' ),
        'add_new'            => __( 'Thêm mới Cửa Hàng', 'text-domain' ),
        'add_new_item'       => __( 'Thêm mới Cửa Hàng', 'text-domain' ),
        'edit_item'          => __( 'Sửa Cửa Hàng', 'text-domain' ),
        'new_item'           => __( 'Cửa Hàng mới', 'text-domain' ),
        'view_item'          => __( 'Xem Cửa Hàng', 'text-domain' ),
        'search_items'       => __( 'Tìm kiếm Cửa Hàng', 'text-domain' ),
        'not_found'          => __( 'Không tìm thấy Cửa Hàng', 'text-domain' ),
        'not_found_in_trash' => __( 'Không tìm thấy Cửa Hàng trong thùng rác', 'text-domain' ),
    );
    $args = array(
        'labels'              => $labels,
        'public'              => true,
        'show_ui'             => true,
        'show_in_menu'        => true,
        'query_var'           => true,
        'rewrite'             => array( 'slug' => 'store-system' ),
        'capability_type'     => 'post',
        'has_archive'         => true,
        'hierarchical'        => false,
        'menu_position'       => null,
        'supports'            => array( 'title', 'editor', 'author', 'thumbnail', 'excerpt', 'comments' ),
        'menu_icon'           => 'dashicons-store', // Change the icon to 'dashicons-store'
        'taxonomies'          => array('city_cat' ), // Enable support for categories and your custom taxonomy "city_cat"
    );
    register_post_type( 'store_system', $args );
    // Register "City Category" custom taxonomy
    register_taxonomy( 'city_cat', 'store_system', array(
        'label' => __( 'Thêm Tỉnh thành', 'text-domain' ),
        'rewrite' => array( 'slug' => 'city-category' ),
        'hierarchical' => true,
        'public' => true,
        'show_ui' => true,
    ) );

    // Thêm trường "dien_thoia" vào custom post type "store_system"
    add_action( 'add_meta_boxes', 'add_dien_thoia_meta_box' );

    function add_dien_thoia_meta_box() {
        add_meta_box(
            'dien_thoia', // ID của metabox
            'Điện thoại', // Tiêu đề của metabox
            'dien_thoia_meta_box_callback', // Callback function hiển thị nội dung metabox
            'store_system', // Post type sử dụng metabox
            'normal', // Vị trí hiển thị của metabox (normal, side, advanced)
            'default' // Ưu tiên hiển thị của metabox (default, high, low)
        );
    }

    function dien_thoia_meta_box_callback() {
        $value = get_post_meta( get_the_ID(), 'dien_thoia', true );
        echo '<input type="text" id="dien_thoia" name="dien_thoia" value="' . esc_attr( $value ) . '" />';
    }

    // Thêm trường "dia_chi" vào custom post type "store_system"
    add_action( 'add_meta_boxes', 'add_dia_chi_meta_box' );

    function add_dia_chi_meta_box() {
        add_meta_box(
            'dia_chi', // ID of the metabox
            'Địa chỉ', // Title of the metabox
            'dia_chi_meta_box_callback', // Callback function to display the metabox content
            'store_system', // Post type to use the metabox
            'normal', // Location to display the metabox (normal, side, advanced)
            'default' // Priority of the metabox (default, high, low)
        );
    }

    function dia_chi_meta_box_callback() {
        $value = get_post_meta( get_the_ID(), 'dia_chi', true );
        echo '<input type="text" id="dia_chi" name="dia_chi" value="' . esc_attr( $value ) . '" />';
    }

}
add_action( 'init', 'custom_post_type_store_system' );

function save_dia_chi_meta_box_data($post_id) {
    if (isset($_POST['dia_chi'])) {
        update_post_meta($post_id, 'dia_chi', sanitize_text_field($_POST['dia_chi']));
    }
}
add_action('save_post', 'save_dia_chi_meta_box_data');
// Save meta box data when the post is saved
function save_dien_thoia_meta_box_data($post_id) {
    if (isset($_POST['dien_thoia'])) {
        update_post_meta($post_id, 'dien_thoia', sanitize_text_field($_POST['dien_thoia']));
    }
}
add_action('save_post', 'save_dien_thoia_meta_box_data');





function store_system_render_settings() {
    ?>
    <div class="wrap">
        <h1>Cài đặt hệ thống cửa hàng</h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('store_system_settings_group');
            do_settings_sections('store_system_settings_page');
            submit_button();
            ?>
        </form>
    </div>
    <?php
}

function store_system_settings_init() {
    // Đăng ký nhóm tùy chọn
    register_setting(
        'store_system_settings_group',
        'store_system_option_title_sons'
    );

    register_setting(
        'store_system_settings_group',
        'store_system_option_name_sons'
    );

    // Đăng ký trang cấu hình
    add_settings_section(
        'store_system_settings_section',
        'Cài đặt Store System',
        'store_system_settings_section_callback',
        'store_system_settings_page'
    );

    // Đăng ký các trường tùy chọn vào trang cấu hình
    add_settings_field(
        'store_system_option_title_sons',
        'Tiêu Đề',
        'store_system_option_phone_callback',
        'store_system_settings_page',
        'store_system_settings_section'
    );

    add_settings_field(
        'store_system_option_name_sons',
        'Nội Dung',
        'store_system_option_address_callback',
        'store_system_settings_page',
        'store_system_settings_section'
    );
}
add_action('admin_init', 'store_system_settings_init');

function store_system_settings_section_callback() {
    echo 'Nhập các tùy chọn cài đặt cho plugin Cài đặt hệ thống cửa hàng:';
    echo '<br>';
    echo 'Sử dụng shortcode [devvn_store_son] để hiển thị trong trang web';
    echo '<br>';
    echo 'Danh mục cha là tỉnh thành danh mục con là quận huyện';
    echo '<br>';
    echo 'phần single có Cửa hàng Sidebar trong phần  widget bạn có thể vào kéo thả widget cho phần single  ';
}

function store_system_option_phone_callback() {
    $option_value = get_option('store_system_option_title_sons', 'TÌM CỬA HÀNG THÁI SƠN');
    echo '<input type="text" name="store_system_option_title_sons" value="' . esc_attr($option_value) . '" />';
}

function store_system_option_address_callback() {
    $option_value = get_option('store_system_option_name_sons', 'Chào đón bạn ghé thăm:');
    echo '<input type="text" name="store_system_option_name_sons" value="' . esc_attr($option_value) . '" />';
}

function store_system_settings_page() {
    add_submenu_page(
        'edit.php?post_type=store_system', // Parent slug của trang Cửa hàng
        'Cài đặt Store System', // Tiêu đề trang cấu hình
        'Cài đặt', // Tiêu đề trong menu admin
        'manage_options', // Quyền truy cập để xem trang cấu hình (ở đây sử dụng quyền 'manage_options' để chỉ cho phép quản trị viên truy cập)
        'store_system_settings', // Slug của trang cấu hình (dùng để xây dựng URL của trang)
        'store_system_render_settings' // Callback function để hiển thị nội dung trang cấu hình
    );
}
add_action('admin_menu', 'store_system_settings_page');

?>